BridgeResponseContext class final

Context for a native response passing through the response middleware chain.

Constructors

BridgeResponseContext({required BridgeEnvelope requestEnvelope, required BridgeEnvelope responseEnvelope})
Creates a BridgeResponseContext.

Properties

extra Map<String, Object?>
Extra context forwarded from the request middleware chain.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
requestEnvelope BridgeEnvelope
The original outgoing request envelope.
final
responseEnvelope BridgeEnvelope
The incoming response envelope from native.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited